brain_dev_firebase_login

this plugin use https://pub.dev/packages/firebase_auth.

Firebase Auth for Flutter

pub package

A Flutter plugin to use the Firebase Authentication API.

To learn more about Firebase Auth, please visit the Firebase website

Getting Started

This project is a starting point for a Flutter plug-in package, a specialized package that includes platform-specific implementation code for Android and/or iOS.

For help getting started with Flutter development, view the online documentation, which offers tutorials, samples, guidance on mobile development, and a full API reference.