FirebaseAuthController class

Inheritance
  • Object
  • GetLifeCycle
  • DisposableInterface
  • GetxController
  • FirebaseAuthController
Implemented types

Constructors

FirebaseAuthController({required SenderFirebaseMessageService senderFirebaseMessageService, required UserRepository userRepository, required SharedPreferences sharedPreferences})

Properties

businessController ↔ BusinessController
getter/setter pair
currentUser → User?
no setter
currentUserFireBase → User?
no setter
firebaseAuth → FirebaseAuth
final
hashCode int
The hash code for this object.
no setterinherited
hasListeners bool
no setterinherited
initialized bool
Checks whether the controller has already been initialized.
no setterinherited
isClosed bool
Checks whether the controller has already been closed.
no setterinherited
isEmailVerified bool
no setter
isEmailVerifiedSink bool
no setter
listeners int
no setterinherited
onDelete → InternalFinalCallback<void>
Internal callback that starts the cycle of this controller.
finalinherited
onStart → InternalFinalCallback<void>
Called at the exact moment the widget is allocated in memory. It uses an internal "callable" type, to avoid any @overrides in subclases. This method should be internal and is required to define the lifetime cycle of the subclass.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
senderFirebaseMessageService → SenderFirebaseMessageService
final
sharedPreferences → SharedPreferences
final
showProgressBar bool
no setter
userRepository ↔ UserRepository
getter/setter pair

Methods

$configureLifeCycle() → void
inherited
addListener(GetStateUpdate listener) → Disposer
Register a closure to be called when the object notifies its listeners.
inherited
addListenerId(Object? key, GetStateUpdate listener) → Disposer
inherited
checkVerificationEmailAction() Future
confirmationDeleteAccount() → dynamic
confirmationDeleteAllDataAccount() → dynamic
createWithEmailAndPassword({required String nomComplet, required String userName, required String password}) Future<void>
deleteAccount({required String raison}) → dynamic
deleteAllDataUser({required String raison}) → dynamic
deleteEmailOnFirebaseAndSignOut() → dynamic
dispose() → void
inherited
disposeId(Object id) → void
To dispose an id from future updates(), this ids are registered by GetBuilder() or similar, so is a way to unlink the state change with the Widget from the Controller.
inherited
getErrorMessage(PlatformException e) String
getErrorMessageAPI({required int code, required String msg}) String
initFirebaseAuth() → dynamic
loginRegisterProvider({required UserModel user, String? redirect}) Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
notifyChildrens() → void
inherited
onClose() → void
Called before onDelete method. onClose might be used to dispose resources used by the controller. Like closing events, or streams before the controller is destroyed. Or dispose objects that can potentially create some memory leaks, like TextEditingControllers, AnimationControllers. Might be useful as well to persist some data on disk.
inherited
onInit() → void
Called immediately after the widget is allocated in memory. You might use this to initialize something for the controller.
inherited
onReady() → void
Called 1 frame after onInit(). It is the perfect place to enter navigation events, like snackbar, dialogs, or a new route, or async request.
inherited
refresh() → void
inherited
refreshGroup(Object id) → void
inherited
removeListener(VoidCallback listener) → void
Remove a previously registered closure from the list of closures that the object notifies.
inherited
removeListenerId(Object id, VoidCallback listener) → void
inherited
sendPasswordResetEmail({required String userName}) Future
sendVerificationEmail() Future
showDialogProgress({bool show = true}) → dynamic
signInWithApple({String? redirect}) Future<void>
signInWithEmailAndPassword({required String userName, required String password, String? redirect}) Future
signInWithFacebook({String? redirect}) Future<void>
signInWithGoogle({String? redirect}) Future<void>
signOut() → void
toString() String
A string representation of this object.
inherited
update([List<Object>? ids, bool condition = true]) → void
Rebuilds GetBuilder each time you call update(); Can take a List of ids, that will only update the matching GetBuilder( id: ), ids can be reused among GetBuilders like group tags. The update will only notify the Widgets, if condition is true.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited