brain_dev_firebase_login
this plugin use https://pub.dev/packages/firebase_auth.
Firebase Auth for Flutter
A Flutter plugin to use the Firebase Authentication API.
To learn more about Firebase Auth, please visit the Firebase website
Getting Started
This project is a starting point for a Flutter plug-in package, a specialized package that includes platform-specific implementation code for Android and/or iOS.
For help getting started with Flutter development, view the online documentation, which offers tutorials, samples, guidance on mobile development, and a full API reference.
Libraries
- brain_dev_firebase_login
- brain_dev_firebase_login_method_channel
- brain_dev_firebase_login_platform_interface
- brain_dev_firebase_login_web
- config/api/api_constant
- config/dependencies_tools
- config/routes/route_helper
- config/routes/route_name
- config/routes/routes
- controllers/auth/firebase_auth_controller
- security/delete_profil_dialog
- security/login_page
- security/profile_edit_screen
- security/recovery_password_page
- security/register_page
- security/verify_email_page
- variables_firebase_login
- views/information-screen/information_screen
- views/message_login_page